==> immibis-core-54.0.0.jar: src/mods/immibis/core/ICNonCoreMod.java <==
package mods.immibis.core;

import mods.immibis.core.api.FMLModInfo;
import mods.immibis.core.api.porting.SidedProxy;
import cpw.mods.fml.common.Mod;
import cpw.mods.fml.common.Mod.Init;
import cpw.mods.fml.common.Mod.PostInit;
import cpw.mods.fml.common.Mod.PreInit;
import cpw.mods.fml.common.event.FMLInitializationEvent;
import cpw.mods.fml.common.event.FMLPostInitializationEvent;
import cpw.mods.fml.common.event.FMLPreInitializationEvent;
import cpw.mods.fml.common.network.NetworkMod;

@Mod(version=ImmibisCore.VERSION, modid=ImmibisCore.MODID, name=ImmibisCore.NAME, dependencies="before:IC2")
@NetworkMod(clientSideRequired=true, serverSideRequired=false)
@FMLModInfo(
		url="http://www.minecraftforum.net/topic/1001131-110-immibiss-mods-smp/",
		description="",
		authors="immibis"
		)
public class ICNonCoreMod {
	@cpw.mods.fml.common.SidedProxy(
			clientSide = "mods.immibis.core.porting.ClientProxy142",
			serverSide = "mods.immibis.core.porting.ServerProxy142")
	public static SidedProxy sidedProxy;
	
	public boolean disabled = false;
	
	public ICNonCoreMod() {
		if(ImmibisCore.instance != null)
			disabled = true;
		else {
			ImmibisCore.instance = new ImmibisCore();
		}
	}
	
	@PreInit
	public void preinit(FMLPreInitializationEvent evt) {
		if(!disabled) {
			ImmibisCore.sidedProxy = sidedProxy;
			ImmibisCore.instance.preInit(evt);
		}
	}
	
	@Init
	public void init(FMLInitializationEvent evt) {
		if(!disabled)
			ImmibisCore.instance.init(evt);
	}
	
	@PostInit
	public void postinit(FMLPostInitializationEvent evt) {
		if(!disabled)
			ImmibisCore.instance.postInit(evt);
	}
}

==> immibis-core-57.1.6.jar: src/mods/immibis/core/ICNonCoreMod.java <==
package mods.immibis.core;

import mods.immibis.core.api.FMLModInfo;
import mods.immibis.core.api.porting.SidedProxy;
import cpw.mods.fml.common.Mod;
import cpw.mods.fml.common.Mod.EventHandler;
import cpw.mods.fml.common.event.FMLInitializationEvent;
import cpw.mods.fml.common.event.FMLPostInitializationEvent;
import cpw.mods.fml.common.event.FMLPreInitializationEvent;
import cpw.mods.fml.common.event.FMLServerStartingEvent;
import cpw.mods.fml.common.network.NetworkMod;

@Mod(version=ImmibisCore.VERSION, modid=ImmibisCore.MODID, name=ImmibisCore.NAME, dependencies="before:IC2")
@NetworkMod(clientSideRequired=true, serverSideRequired=false)
@FMLModInfo(
		url="http://www.minecraftforum.net/topic/1001131-110-immibiss-mods-smp/",
		description="",
		authors="immibis"
		)
public class ICNonCoreMod {
	@cpw.mods.fml.common.SidedProxy(
			clientSide = "mods.immibis.core.porting.ClientProxy142",
			serverSide = "mods.immibis.core.porting.ServerProxy142")
	public static SidedProxy sidedProxy;
	
	public boolean disabled = false;
	
	public ICNonCoreMod() {
		if(ImmibisCore.instance != null)
			disabled = true;
		else
			ImmibisCore.instance = new ImmibisCore();
	}
	
	@EventHandler
	public void preinit(FMLPreInitializationEvent evt) {
		if(!disabled) {
			SidedProxy.instance = sidedProxy;
			ImmibisCore.instance.preInit(evt);
		}
	}
	
	@EventHandler
	public void init(FMLInitializationEvent evt) {
		if(!disabled)
			ImmibisCore.instance.init(evt);
	}
	
	@EventHandler
	public void postinit(FMLPostInitializationEvent evt) {
		if(!disabled)
			ImmibisCore.instance.postInit(evt);
	}
	
	@EventHandler
	public void serverStarting(FMLServerStartingEvent evt) {
		if(!disabled)
			ImmibisCore.instance.serverStarting(evt);
	}
}
